import { StringUtilsErrorMap } from './TYPES';
/**
 * Error class whose instance is thrown in case of any error.
 *
 * @class
 * @typedef {StringUtilsError}
 * @extends {Error}
 */
export default class StringUtilsError extends Error {
    /**
     * Flag to identify if error is a custom error.
     */
    readonly _isCustomError = true;
    /**
     * Flag to identify if error is a StringUtilsError.
     */
    readonly _isStringUtilsError = true;
    /**
     * Node project from which Error is thrown.
     */
    readonly service: string;
    /**
     * Error's message string.
     */
    message: string;
    /**
     * HTTP status code associated with the error.
     */
    statusCode: number;
    /**
     * Error Code.
     */
    errorCode: string;
    /**
     * Error object.
     */
    error?: any;
    /**
     * Creates an instance of StringUtilsError.
     *
     * @constructor
     * @param [e] Any Error instance to wrap with StringUtilsError.
     * @param [eMap] StringUtilsErrorMap to rewrap error for better understanding.
     */
    constructor(e: any, eMap: StringUtilsErrorMap);
}
